@@ -21,7 +21,12 @@
 
 #include "jack.h"
 
+#ifdef FORBMP
+#include <beep-media-player/bmp/configfile.h>
+#else
 #include <xmms/configfile.h>
+#endif
+
 #include <gtk/gtk.h>
 
 extern jackconfig jack_cfg;
@@ -37,8 +42,13 @@ static void configure_win_ok_cb(GtkWidget * w, gpointer data)
 	gchar *filename;
 
 	jack_cfg.isTraceEnabled = (gint) GTK_CHECK_BUTTON(GTK_isTraceEnabled)->toggle_button.active;
-
+	
+	#ifdef FORBMP
+	filename = g_strconcat(g_get_home_dir(), "/.bmp/config", NULL);
+	#else
 	filename = g_strconcat(g_get_home_dir(), "/.xmms/config", NULL);
+	#endif
+	
 	cfgfile = xmms_cfg_open_file(filename);
 	if (!cfgfile)
 		cfgfile = xmms_cfg_new();
@@ -57,7 +67,11 @@ void jack_configure(void)
 
 	if (!configure_win)
 	{
+		#ifdef FORBMP		
+		configure_win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+		#else
 		configure_win = gtk_window_new(GTK_WINDOW_DIALOG);
+		#endif
 		gtk_signal_connect(GTK_OBJECT(configure_win), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &configure_win);
 		gtk_window_set_title(GTK_WINDOW(configure_win), ("jack Plugin configuration"));
 		gtk_window_set_policy(GTK_WINDOW(configure_win), FALSE, FALSE, FALSE);
