@@ -4,7 +4,11 @@
  *	This code maps xmms calls into the jack translation library
  */
 
+#ifdef FORBMP
+#include <beep-media-player/bmp/configfile.h>
+#else
 #include <xmms/configfile.h>
+#endif
 #include <dlfcn.h>
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -179,7 +183,11 @@ void jack_init(void)
   ConfigFile *cfgfile;
   gchar *filename;
 
+  #ifdef FORBMP
+  filename = g_strconcat(g_get_home_dir(), "/.bmp/config", NULL);
+  #else
   filename = g_strconcat(g_get_home_dir(), "/.xmms/config", NULL);
+  #endif
   cfgfile = xmms_cfg_open_file(filename);
   if (!cfgfile)
       jack_cfg.isTraceEnabled = FALSE;
@@ -513,10 +521,10 @@ void jack_get_volume(int *l, int *r)
 void jack_about(void)
 {
 	dialog = gtk_dialog_new();
-	gtk_window_set_title(GTK_WINDOW(dialog), ("About jack Driver 0.12"));
+	gtk_window_set_title(GTK_WINDOW(dialog), ("About jack Driver 0.14"));
 	gtk_container_border_width(GTK_CONTAINER(dialog), 5);
 	label = gtk_label_new((
-		"XMMS jack Driver 0.12\n\n "
+		"XMMS jack Driver 0.14\n\n "
 		"xmms-jack.sf.net\n"
 		"Chris Morgan<cmorgan@alum.wpi.edu>\n"));
 
